@@ -227,7 +227,7 @@ RunICA <- function(
 #' \item{Rtsne: }{Use the Rtsne package Barnes-Hut implementation of tSNE (default)}
 #' \item{tsne: }{standard tsne - not recommended for large datasets}
 #' \item{FIt-SNE: }{Use the FFT-accelerated Interpolation-based t-SNE. Based on
-#' Kluger Lab code found here: https://github.com/ChristophH/FIt-SNE}
+#' Kluger Lab code found here: https://github.com/KlugerLab/FIt-SNE}
 #' }
 #' @param add.iter If an existing tSNE has already been computed, uses the
 #' current tSNE to seed the algorithm and then adds additional iterations on top
@@ -775,6 +775,7 @@ RunCCA <- function(
 #' @export
 #'
 #' @examples
+#' \dontrun{
 #' pbmc_small
 #' # As multi-set CCA requires more than two datasets, we will split our test object into
 #' # three just for this example
@@ -788,6 +789,7 @@ RunCCA <- function(
 #' pbmc_cca <- RunMultiCCA(object.list = pbmc.list, genes.use = pbmc_small@var.genes, num.ccs = 3)
 #' # Print results
 #' PrintDim(pbmc_cca,reduction.type = 'cca')
+#' }
 #'
 RunMultiCCA <- function(
   object.list,
@@ -938,6 +940,12 @@ RunMultiCCA <- function(
 
 #' Run diffusion map
 #'
+#' NOTE: Prior to v2.3.4, this function used the R package diffusionMap to compute
+#' the diffusion map components. This package was being archived and thus
+#' RunDiffusion now uses the destiny package for the diffusion computations.
+#' Please be aware that this will result in different default values as the two
+#' underlying package implementations are different.
+#'
 #' @param object Seurat object
 #' @param cells.use Which cells to analyze (default, all cells)
 #' @param dims.use Which dimensions to use as input features
@@ -946,21 +954,26 @@ RunMultiCCA <- function(
 #' default
 #' @param reduction.use Which dimensional reduction (PCA or ICA) to use for the
 #' diffusion map input. Default is PCA
-#' @param q.use Quantile to clip diffusion map components at. This addresses an issue where 1-2 cells will have extreme values that obscure all other points. 0.01 by default
+#' @param q.use Quantile to clip diffusion map components at. This addresses an
+#' issue where 1-2 cells will have extreme values that obscure all other points.
+#' 0.01 by default
 #' @param max.dim Max dimension to keep from diffusion calculation
 #' @param scale.clip Max/min value for scaled data. Default is 3
-#' @param reduction.name dimensional reduction name, specifies the position in the object$dr list. dm by default
-#' @param reduction.key dimensional reduction key, specifies the string before the number for the dimension names. DM by default
-#' @param ... Additional arguments to the diffuse call
+#' @param reduction.name dimensional reduction name, specifies the position in
+#' the object$dr list. dm by default
+#' @param reduction.key dimensional reduction key, specifies the string before
+#' the number for the dimension names. DM by default
+#' @param ... Additional arguments to the DiffusionMap call
 #'
 #' @return Returns a Seurat object with a diffusion map
 #'
-#' @import diffusionMap
+#' @importFrom utils installed.packages
 #' @importFrom stats dist quantile
 #'
 #' @export
 #'
 #' @examples
+#' \dontrun{
 #' pbmc_small
 #' # Run Diffusion on variable genes
 #' pbmc_small <- RunDiffusion(pbmc_small,genes.use = pbmc_small@var.genes)
@@ -968,6 +981,7 @@ RunMultiCCA <- function(
 #' pbmc_small <- RunDiffusion(pbmc_small,genes.use = pbmc_small@var.genes)
 #' # Plot results
 #' DMPlot(pbmc_small)
+#' }
 #'
 RunDiffusion <- function(
   object,
@@ -982,6 +996,10 @@ RunDiffusion <- function(
   reduction.key = "DM",
   ...
 ) {
+  # Check for destiny
+  if (!'destiny' %in% rownames(x = installed.packages())) {
+    stop("Please install destiny - learn more at https://bioconductor.org/packages/release/bioc/html/destiny.html")
+  }
   cells.use <- SetIfNull(x = cells.use, default = colnames(x = object@data))
   if (is.null(x = genes.use)) {
     dim.code <- GetDimReduction(
@@ -1006,12 +1024,8 @@ RunDiffusion <- function(
                           ... = parameters.to.store)
   data.dist <- dist(data.use)
   data.diffusion <- data.frame(
-    diffuse(
-      D = data.dist,
-      neigen = max.dim,
-      maxdim = max.dim,
-      ...
-    )$X
+    destiny::DiffusionMap(data = as.matrix(data.dist),
+                          n_eigs = max.dim, ...)@eigenvectors
   )
   colnames(x = data.diffusion) <- paste0(reduction.key, 1:ncol(x = data.diffusion))
   rownames(x = data.diffusion) <- cells.use
@@ -1045,7 +1059,8 @@ RunDiffusion <- function(
 #' **high** dimensional data in **low** dimensional spaces.
 #' To run, you must first install the `phate` python
 #' package (e.g. via pip install phate). Details on this package can be
-#' found here: \url{https://github.com/KrishnaswamyLab/PHATE}. For a more in depth
+#' found here: \url{https://github.com/KrishnaswamyLab/PHATE}. For help,
+#' visit \url{https://krishnaswamylab.org/get-help}. For a more in depth
 #' discussion of the mathematics underlying PHATE, see the bioRxiv paper here:
 #' \url{https://www.biorxiv.org/content/early/2017/12/01/120378}.
 #'
@@ -1055,41 +1070,37 @@ RunDiffusion <- function(
 #' Not set (NULL) by default
 #' @param assay.type Assay to pull data for (default: 'RNA')
 #' @param max.dim Total number of dimensions to embed in PHATE.
-#' @param k int, optional, default: 15
+#' @param k int, optional (default: 5)
 #' number of nearest neighbors on which to build kernel
-#' @param alpha int, optional, default: 10
+#' @param alpha int, optional (default: 15)
 #' sets decay rate of kernel tails.
 #' If NA, alpha decaying kernel is not used
-#' @param use.alpha boolean, default: NA
-#' forces the use of alpha decaying kernel
-#' If NA, alpha decaying kernel is used for small inputs
-#' (n_samples < n_landmark) and not used otherwise
-#' @param n.landmark int, optional, default: 2000
+#' @param n.landmark int, optional (default: 2000)
 #' number of landmarks to use in fast PHATE
-#' @param potential.method string, optional, default: 'log'
-#' choose from 'log' and 'sqrt'
-#' which transformation of the diffusional operator is used
-#' to compute the diffusion potential
-#' @param t int, optional, default: 'auto'
+#' @param gamma float, optional (default: 1)
+#' Informational distance constant between -1 and 1.
+#' `gamma=1` gives the PHATE log potential, `gamma=0` gives
+#' a square root potential.
+#' @param t int, optional (default: 'auto')
 #' power to which the diffusion operator is powered
 #' sets the level of diffusion
-#' @param knn.dist.method string, optional, default: 'euclidean'.
+#' @param knn.dist.method string, optional (default: 'euclidean')
 #' The desired distance function for calculating pairwise distances on the data.
 #' If 'precomputed', `data` is treated as a
 #' (n_samples, n_samples) distance or affinity matrix
-#' @param mds.method string, optional, default: 'metric'
+#' @param mds.method string, optional (default: 'metric')
 #' choose from 'classic', 'metric', and 'nonmetric'
 #' which MDS algorithm is used for dimensionality reduction
-#' @param mds.dist.method string, optional, default: 'euclidean'
+#' @param mds.dist.method string, optional (default: 'euclidean')
 #' recommended values: 'euclidean' and 'cosine'
-#' @param t.max int, optional, default: 100.
+#' @param t.max int, optional (default: 100)
 #' Maximum value of t to test for automatic t selection.
-#' @param npca int, optional, default: 100
+#' @param npca int, optional (default: 100)
 #' Number of principal components to use for calculating
 #' neighborhoods. For extremely large datasets, using
 #' n_pca < 20 allows neighborhoods to be calculated in
 #' log(n_samples) time.
-#' @param plot.optimal.t boolean, optional, default: FALSE
+#' @param plot.optimal.t boolean, optional (default: FALSE)
 #' If TRUE, produce a plot showing the Von Neumann Entropy
 #' curve for automatic t selection.
 #' @param verbose `int` or `boolean`, optional (default : 1)
@@ -1134,8 +1145,8 @@ RunDiffusion <- function(
 #' # Plot results
 #' DimPlot(object = pbmc_small, reduction.use = 'phate')
 #'1
-#' # For increased emphasis on local structure, use sqrt potential
-#' pbmc_small <- RunPHATE(object = pbmc_small, potential.method='sqrt')
+#' # For increased emphasis on local structure, use sqrt potential (gamma=0)
+#' pbmc_small <- RunPHATE(object = pbmc_small, gamma=0)
 #' # Plot results
 #' DimPlot(object = pbmc_small, reduction.use = 'phate')
 #' }
@@ -1146,11 +1157,10 @@ RunPHATE <- function(
   genes.use = NULL,
   assay.type = 'RNA',
   max.dim = 2L,
-  k = 15,
-  alpha = 10,
-  use.alpha = NA,
+  k = 5,
+  alpha = 15,
   n.landmark = 2000,
-  potential.method = "log",
+  gamma = 1,
   t = "auto",
   knn.dist.method = "euclidean",
   mds.method = "metric",
@@ -1189,7 +1199,6 @@ RunPHATE <- function(
     alpha = alpha,
     use.alpha = alpha,
     n.landmark = n.landmark,
-    potential.method = potential.method,
     t = t,
     knn.dist.method = knn.dist.method,
     init = NULL,
